==> estateplat-common-1.2.4-20201112.062002-497-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxGaRkJzxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/12
 * @description 省级信息共享-公安-人口-基准信息
 */
@Table(name = "xxgx_ga_rk_jzxx")
public class XxgxGaRkJzxx {
    @Id
    private String jzxxid;//基准信息id
    private String gmxm;//公民姓名
    private String gmsfh;//公民身份号
    private String sfzhppd;//公民身份证号匹配度代码
    private String xmppd;//姓名匹配度
    private String gjdqm;//国家地区码
    private String ssxdqm;//出生地_省市县地区码（行政区划代码）
    private Date csrq;//出生日期
    private String mzdm;//民族代码
    private String swbs;//死亡标识
    private String xbdm;//性别代码
    private String proid;//项目id
    private String qlrid;//权利人id

    public String getJzxxid() {
        return jzxxid;
    }

    public void setJzxxid(String jzxxid) {
        this.jzxxid = jzxxid;
    }

    public String getGmxm() {
        return gmxm;
    }

    public void setGmxm(String gmxm) {
        this.gmxm = gmxm;
    }

    public String getGmsfh() {
        return gmsfh;
    }

    public void setGmsfh(String gmsfh) {
        this.gmsfh = gmsfh;
    }

    public String getSfzhppd() {
        return sfzhppd;
    }

    public void setSfzhppd(String sfzhppd) {
        this.sfzhppd = sfzhppd;
    }

    public String getXmppd() {
        return xmppd;
    }

    public void setXmppd(String xmppd) {
        this.xmppd = xmppd;
    }

    public String getGjdqm() {
        return gjdqm;
    }

    public void setGjdqm(String gjdqm) {
        this.gjdqm = gjdqm;
    }

    public String getSsxdqm() {
        return ssxdqm;
    }

    public void setSsxdqm(String ssxdqm) {
        this.ssxdqm = ssxdqm;
    }

    public Date getCsrq() {
        return csrq;
    }

    public void setCsrq(Date csrq) {
        this.csrq = csrq;
    }

    public String getMzdm() {
        return mzdm;
    }

    public void setMzdm(String mzdm) {
        this.mzdm = mzdm;
    }

    public String getSwbs() {
        return swbs;
    }

    public void setSwbs(String swbs) {
        this.swbs = swbs;
    }

    public String getXbdm() {
        return xbdm;
    }

    public void setXbdm(String xbdm) {
        this.xbdm = xbdm;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }
}

==> estateplat-common-1.2.4-20241031.072335-1260-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxGaRkJzxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/12
 * @description 省级信息共享-公安-人口-基准信息
 */
@Table(name = "xxgx_ga_rk_jzxx")
public class XxgxGaRkJzxx {
    @Id
    private String jzxxid;//基准信息id
    private String gmxm;//公民姓名
    private String gmsfzh;//公民身份号
    private String sfzhppd;//公民身份证号匹配度代码
    private String xmppd;//姓名匹配度
    private String gjdqm;//国家地区码
    private String ssxdqm;//出生地_省市县地区码（行政区划代码）
    private Date csrq;//出生日期
    private String mzdm;//民族代码
    private String swbs;//死亡标识
    private String xbdm;//性别代码
    private String proid;//项目id
    private String qlrid;//权利人id

    public String getJzxxid() {
        return jzxxid;
    }

    public void setJzxxid(String jzxxid) {
        this.jzxxid = jzxxid;
    }

    public String getGmxm() {
        return gmxm;
    }

    public void setGmxm(String gmxm) {
        this.gmxm = gmxm;
    }

    public String getGmsfzh() {
        return gmsfzh;
    }

    public void setGmsfzh(String gmsfzh) {
        this.gmsfzh = gmsfzh;
    }

    public String getSfzhppd() {
        return sfzhppd;
    }

    public void setSfzhppd(String sfzhppd) {
        this.sfzhppd = sfzhppd;
    }

    public String getXmppd() {
        return xmppd;
    }

    public void setXmppd(String xmppd) {
        this.xmppd = xmppd;
    }

    public String getGjdqm() {
        return gjdqm;
    }

    public void setGjdqm(String gjdqm) {
        this.gjdqm = gjdqm;
    }

    public String getSsxdqm() {
        return ssxdqm;
    }

    public void setSsxdqm(String ssxdqm) {
        this.ssxdqm = ssxdqm;
    }

    public Date getCsrq() {
        return csrq;
    }

    public void setCsrq(Date csrq) {
        this.csrq = csrq;
    }

    public String getMzdm() {
        return mzdm;
    }

    public void setMzdm(String mzdm) {
        this.mzdm = mzdm;
    }

    public String getSwbs() {
        return swbs;
    }

    public void setSwbs(String swbs) {
        this.swbs = swbs;
    }

    public String getXbdm() {
        return xbdm;
    }

    public void setXbdm(String xbdm) {
        this.xbdm = xbdm;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }
}
